@@ -60,6 +60,11 @@ After installing wikir, all `setuptools`_-enabled projects on the same machine w
 Command usage::
 
     $ python setup.py publish_wiki --help
+    | Common commands: (see '--help-commands' for more)
+    | 
+    |   setup.py build      will build the package underneath 'build/'
+    |   setup.py install    will install the package
+    | 
     | Global options:
     |   --verbose (-v)  run verbosely (default)
     |   --quiet (-q)    run quietly (turns verbosity off)
@@ -76,6 +81,7 @@ Command usage::
     |    or: setup.py cmd --help
     | 
 
+
 Publishing RST To Wiki
 ++++++++++++++++++++++
 
@@ -148,7 +154,7 @@ If you don't want to use wikir through setup.py you can use the command line scr
 Command usge::
 
     $ wikir --help
-    | usage: wikir [options] path/to/module.py
+    | Usage: wikir [options] path/to/module.py
     |        wikir [options] path/to/file.txt
     | 
     | Publish RST documents in Wiki format
@@ -156,7 +162,7 @@ Command usge::
     | 1. finds the top-most docstring of module.py, parses as RST, and prints Wiki format to STDOUT
     | 2. parses file.txt (or a file with any other extension) as RST and prints Wiki format to STDOUT
     | 
-    | options:
+    | Options:
     |   -h, --help  show this help message and exit
 
 You can publish a module's docstring written in RST format to Wiki format like so::
@@ -258,6 +264,6 @@ If you're not there already, `wikir lives on Google Code`_.
 .. _wikir lives on Google Code: http://code.google.com/p/wikir/
 
 """
-__version__ = '0.3'
+__version__ = '0.4'
 
 from wikir import *
\ No newline at end of file
