@@ -35,7 +35,7 @@ def match(left, right, show=False, context=''):
             s + '=' + name + sep]))
     if context:
         context = dump(context, 'CONTEXT') + u"\n"
-    comparison = u"\n%s%s\n%s" %  (context, dump(left, 'LEFT'), dump(right, 'RIGHT'))
+    comparison = u"\n%s%s\n%s" %  (context, dump(left, 'ACTUAL'), dump(right, 'EXPECTED'))
     if show:
         print comparison.encode('utf-8')
     msg = u"\n%s\n(strings did not match)" % comparison
