@@ -143,6 +143,99 @@ class WikiVisitor(SparseNodeVisitor):
         elif not auto_url_re.search(node.astext()):
             self.output.append('[' + href + ' ')
 
+    def visit_definition(self, node):
+        # spaces are what creates a definition in google wiki :
+        self.output.append('\n  ') 
+
+    def depart_definition(self, node):
+        self.output.append('\n')
+
+    def visit_definition_list(self, node):
+        pass
+
+    def depart_definition_list(self, node):
+        pass
+
+    def visit_definition_list_item(self, node):
+        pass
+    
+    def visit_classifier(self, node):
+        self.output.append(' : ')
+        # enter bold for definition classifier:
+        # i.e.
+        # definition-term : _the-classifier_
+        #   the definition
+        self.output.append('_') 
+    
+    def depart_classifier(self, node):
+        # exit bold for definition classifier:
+        # i.e.
+        # definition-term : _the-classifier_
+        #   the definition
+        self.output.append('_')
+
+    def visit_term(self, node):
+        pass
+
+    def depart_term(self, node):
+        pass
+
+    def depart_definition_list_item(self, node):
+        pass
+        
+
+    def visit_option(self, node):
+        self.output.append('`')
+
+    def depart_option(self, node):
+        self.output.append('`')
+        
+        # it seems difficult to add a comment 
+        # between options, like this:
+        # -h, --help
+        
+        # next_node = node.next_node()
+        # print "<-"
+        # print node
+        # print node.__class__
+        # print "->"
+        # print next_node
+        # print next_node.__class__
+        # if isinstance(next_node, nodes.option_string):
+        #     self.output.append(',')
+
+        self.output.append(' ')
+
+    def visit_option_argument(self, node):
+        self.output.append('=')
+
+    def depart_option_argument(self, node):
+        pass
+
+    def visit_option_group(self, node):
+        pass
+
+    def depart_option_group(self, node):
+        self.output.append("\n  ")
+
+    def visit_option_list(self, node):
+        pass
+
+    def depart_option_list(self, node):
+        pass
+
+    def visit_option_list_item(self, node):
+        pass
+
+    def depart_option_list_item(self, node):
+        pass
+
+    def visit_option_string(self, node):
+        pass
+
+    def depart_option_string(self, node):
+        pass
+
     def depart_reference(self, node):
         if 'contents' in self.topic_classes:
             self.output.append('')
